==> jaulp.swing-3.12.0-sources.jar: de/alpharogroup/generic/mvc/view/View.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2007 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.generic.mvc.view;

import java.awt.Component;

/**
 * The Interface View.
 *
 * @param <C>
 *            the generic type of the controller
 * @param <COMP>
 *            the generic type of the component
 */
public interface View<C, COMP extends Component>
{

	/**
	 * Gets the controller.
	 *
	 * @return the controller
	 */
	C getController();

	/**
	 * Sets the controller.
	 *
	 * @param controller
	 *            the new controller
	 */
	void setController(C controller);

	/**
	 * Gets the component.
	 *
	 * @return the component
	 */
	COMP getComponent();

	/**
	 * Sets the component.
	 *
	 * @param component
	 *            the new component
	 */
	void setComponent(COMP component);

	/**
	 * Checks for parent.
	 *
	 * @return true, if successful
	 */
	boolean hasParent();

	/**
	 * Gets the parent.
	 *
	 * @return the parent
	 */
	View<?, ?> getParent();


}

==> jaulp.swing-4.1.0-sources.jar: de/alpharogroup/generic/mvc/view/View.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2007 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.generic.mvc.view;

import java.awt.Component;

/**
 * The Interface View.
 *
 * @param <C>
 *            the generic type of the controller
 * @param <COMP>
 *            the generic type of the component
 */
public interface View<C, COMP extends Component>
{

	/**
	 * Gets the controller.
	 *
	 * @return the controller
	 */
	C getController();

	/**
	 * Sets the controller.
	 *
	 * @param controller
	 *            the new controller
	 */
	void setController(final C controller);

	/**
	 * Gets the component.
	 *
	 * @return the component
	 */
	COMP getComponent();

	/**
	 * Sets the component.
	 *
	 * @param component
	 *            the new component
	 */
	void setComponent(final COMP component);

	/**
	 * Checks for parent.
	 *
	 * @return true, if successful
	 */
	boolean hasParent();

	/**
	 * Gets the parent.
	 *
	 * @return the parent
	 */
	View<?, ?> getParent();


}
